use strict;
use warnings;
package App::Prefix;

our $VERSION = '0.06';  # version also mentioned in POD below, if it exists

# ABSTRACT: provides 'prefix' filter, which prepends data to lines passed
#
# Copyright 2010-2013 Josh Rabinowitz.

1;
